import type { Metadata } from "next";
import { Inter } from "next/font/google";
import SessionAuthProvider from "@/src/context/SessionAuthProvider";
import { getServerSession } from "next-auth";
import { NextUIProvider } from "@nextui-org/react";
import { ThemeProvider as NextThemesProvider } from "next-themes";
import { Toaster } from 'react-hot-toast';
import "./globals.css";
import { PWAInstallBanner } from "../components/PWAInstallBanner";
import { ServiceWorkerRegistration } from "../utils/ServiceWorkerRegistration";
import Script from "next/script";

const inter = Inter({ subsets: ["latin"] });

export const metadata: Metadata = {
  title: "Multiagente - Chat",
  description: "Multiagente - Chat",
  manifest: `${process.env.ASSET_PREFIX}/manifest.json`,
  icons: {
    icon: `${process.env.ASSET_PREFIX}/chat/assets/images/logo/logo_mua.png`,
    shortcut: `${process.env.ASSET_PREFIX}/chat/assets/images/logo/logo_mua.png`,
    apple: `${process.env.ASSET_PREFIX}/chat/assets/images/logo/logo_mua.png`,
    other: {
      rel: "apple-touch-icon",
      url: `${process.env.ASSET_PREFIX}/chat/assets/images/logo/logo_mua.png`,
    },
  },
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {

  const session = getServerSession();
  const handleSubscriptionChange = (subscription: PushSubscription | null) => {
    if (subscription) {
      console.log('User is subscribed to push notifications');
    } else {
      console.log('User is not subscribed to push notifications');
    }
  };

  return (
    <html lang="es">
      <body className={inter.className}>
        <Script src={`${process.env.ASSET_PREFIX}/push.min.js`} />
        <SessionAuthProvider session={session}>
          <NextUIProvider>
            <NextThemesProvider attribute="class" defaultTheme="light">
              <ServiceWorkerRegistration />
              <PWAInstallBanner />
              {children}
              <Toaster />
            </NextThemesProvider>
          </NextUIProvider>
        </SessionAuthProvider>
      </body>
    </html>
  );
}
